@@ -75,18 +75,22 @@ int ResType::VarNameCmp(const char *good_name,const char *name)
    return res;
 }
 
-const char *ResType::FindVar(const char *name,const ResType **type)
+bool ResType::IsAlias() const
+{
+   return closure_valid==ResMgr::AliasValidate;
+}
+
+const char *ResType::FindVar(const char *name,const ResType **type,const char **re_closure)
 {
    const ResType *exact_proto=0;
    const ResType *exact_name=0;
+   int sub=0;
 
    *type=types_by_name->lookup(name);
    if(*type)
-      return 0;	// exact match
+      goto found; // exact match
 
-   int sub=0;
-   const ResType *type_scan;
-   for(type_scan=types_by_name->each_begin(); type_scan; type_scan=types_by_name->each_next())
+   for(const ResType *type_scan=types_by_name->each_begin(); type_scan; type_scan=types_by_name->each_next())
    {
       switch(VarNameCmp(type_scan->name,name))
       {
@@ -115,12 +119,28 @@ const char *ResType::FindVar(const char *name,const ResType **type)
 	 break;
       }
    }
-   if(!type_scan && sub==0)
+   if(!*type && sub==0)
       return _("no such variable");
    if(sub==1)
-      return 0;
+      goto found;
    *type=0;
    return _("ambiguous variable name");
+
+found:
+   if((*type)->IsAlias()) {
+      const char *alias_c=(*type)->GetAliasTarget();
+      char *alias=alloca_strdup(alias_c);
+      char *slash=strchr(alias,'/');
+      if(slash) {
+	 *slash=0;
+	 if(re_closure)
+	    *re_closure=alias_c+(slash+1-alias);
+      }
+      *type=types_by_name->lookup(alias);
+      if(!*type)
+	 return "invalid compatibility alias";
+   }
+   return 0;
 }
 
 const ResType *ResType::FindRes(const char *name)
@@ -132,18 +152,18 @@ const ResType *ResType::FindRes(const char *name)
    return type;
 }
 
-const char *ResType::Set(const char *name,const char *cclosure,const char *cvalue)
+const char *ResType::Set(const char *name,const char *cclosure,const char *cvalue,bool def)
 {
    ResType *type;
    // find type of given variable
-   const char *msg=FindVar(name,&type);
+   const char *msg=FindVar(name,&type,&cclosure);
    if(msg)
       return msg;
 
-   return type->Set(cclosure,cvalue);
+   return type->Set(cclosure,cvalue,def);
 }
 
-const char *ResType::Set(const char *cclosure,const char *cvalue)
+const char *ResType::Set(const char *cclosure,const char *cvalue,bool def)
 {
    const char *msg=0;
 
@@ -152,7 +172,8 @@ const char *ResType::Set(const char *cclosure,const char *cvalue)
       return msg;
 
    xstring_c closure(cclosure);
-   if(closure && closure_valid && (msg=closure_valid(&closure))!=0)
+   if((closure || closure_valid==ResMgr::HasClosure)
+   && closure_valid && (msg=closure_valid(&closure))!=0)
       return msg;
 
    bool need_reconfig=false;
@@ -162,6 +183,8 @@ const char *ResType::Set(const char *cclosure,const char *cvalue)
       // find the old value
       if(closure==scan->closure || !xstrcmp(scan->closure,closure))
       {
+	 if(def)
+	    return 0;
 	 need_reconfig=true;
 	 delete scan;
 	 break;
@@ -169,7 +192,7 @@ const char *ResType::Set(const char *cclosure,const char *cvalue)
    }
    if(value)
    {
-      (void)new Resource(this,closure,value);
+      (void)new Resource(this,closure,value,def);
       need_reconfig=true;
    }
    if(need_reconfig)
@@ -246,7 +269,7 @@ char *ResType::Format(bool with_defaults,bool only_defaults)
    if(with_defaults || only_defaults)
    {
       for(ResType *dscan=types_by_name->each_begin(); dscan; dscan=types_by_name->each_next())
-	 if(only_defaults || dscan->SimpleQuery(0)==0)
+	 if((only_defaults || dscan->SimpleQuery(0)==0) && !dscan->IsAlias())
 	    created.append(new Resource(dscan,
 	       0,xstrdup(dscan->defvalue?dscan->defvalue:"(nil)")));
    }
@@ -257,8 +280,10 @@ char *ResType::Format(bool with_defaults,bool only_defaults)
    {
       // just created Resources are also in all_list.
       xarray<const Resource*> arr;
-      xlist_for_each(Resource,Resource::all_list,node,scan)
-	 arr.append(scan);
+      xlist_for_each(Resource,Resource::all_list,node,scan) {
+	 if(!scan->def || with_defaults)
+	    arr.append(scan);
+      }
       arr.qsort(PResourceCompare);
       for(int i=0; i<arr.count(); i++)
 	 arr[i]->Format(buf);
@@ -278,7 +303,8 @@ char **ResType::Generator(void)
    StringSet res;
 
    for(ResType *dscan=types_by_name->each_begin(); dscan; dscan=types_by_name->each_next())
-      res.Append(dscan->name);
+      if(!dscan->IsAlias())
+	 res.Append(dscan->name);
 
    res.qsort();
    return res.borrow();
@@ -404,6 +430,11 @@ const char *ResMgr::UNumberValidate(xstring_c *value)
 
    return 0;
 }
+const char *ResMgr::AliasValidate(xstring_c *)
+{
+   return "";
+}
+
 unsigned long long ResValue::to_unumber(unsigned long long max) const
 {
    if (is_nil())
@@ -455,8 +486,8 @@ bool ResValue::to_tri_bool(bool a) const
    return to_bool();
 }
 
-Resource::Resource(ResType *type,const char *closure,const char *value)
-   : type(type), value(value), closure(closure), all_node(this), type_value_node(this)
+Resource::Resource(ResType *type,const char *closure,const char *value,bool def)
+   : type(type), value(value), closure(closure), def(def), all_node(this), type_value_node(this)
 {
    all_list.add_tail(all_node);
    type->type_value_list->add_tail(type_value_node);
@@ -862,6 +893,13 @@ const char *ResMgr::NoClosure(xstring_c *)
    return _("no closure defined for this setting");
 }
 
+const char *ResMgr::HasClosure(xstring_c *c)
+{
+   if(!*c || !**c)
+      return _("a closure is required for this setting");
+   return 0;
+}
+
 const char *ResMgr::UNumberPairValidate(xstring_c *value)
 {
    NumberPair pair(':',*value);
