@@ -357,15 +357,14 @@ static ResType lftp_vars[] = {
 
    {"file:charset",		 "",	  ResMgr::CharsetValidate,ResMgr::NoClosure},
    {"file:use-lock",		 "no",	  ResMgr::BoolValidate,ResMgr::NoClosure},
-#ifdef HAVE_POSIX_FALLOCATE
    {"file:use-fallocate",	 "yes",	  ResMgr::BoolValidate,ResMgr::NoClosure},
-#endif
 
    {"dns:cache-enable",		 "yes",	  ResMgr::BoolValidate,0},
    {"dns:cache-expire",		 "1h",	  ResMgr::TimeIntervalValidate,0},
    {"dns:cache-size",		 "256",	  ResMgr::UNumberValidate,ResMgr::NoClosure},
    {"dns:fatal-timeout",	 "7d",	  ResMgr::TimeIntervalValidate,0},
    {"dns:max-retries",		 "1000",  ResMgr::UNumberValidate,0},
+   {"dns:name",			 "",	  0,ResMgr::HasClosure},
 #if INET6
 # define DEFAULT_ORDER "inet6 inet"
 #else
@@ -388,9 +387,7 @@ static ResType lftp_vars[] = {
    {"xfer:destination-directory","",	  0,0},
    {"xfer:verify",		 "no",	  ResMgr::BoolValidate,ResMgr::NoClosure},
    {"xfer:verify-command",	 "",	  ResMgr::FileExecutable,0},
-   {"xfer:log",			 "yes",	  ResMgr::BoolValidate,ResMgr::NoClosure},
    {"xfer:auto-rename",		 "no",	  ResMgr::BoolValidate,ResMgr::NoClosure},
-   {"xfer:log-file",              "",     ResMgr::FileCreatable,ResMgr::NoClosure},
    {"xfer:max-log-size",	 "1M",	  ResMgr::UNumberValidate,ResMgr::NoClosure},
    {"xfer:use-temp-file",	 "no",	  ResMgr::BoolValidate,ResMgr::NoClosure},
    {"xfer:temp-file-name",	 ".in.*", 0,ResMgr::NoClosure},
@@ -400,6 +397,11 @@ static ResType lftp_vars[] = {
    {"xfer:keep-backup",		 "no",	  ResMgr::BoolValidate,ResMgr::NoClosure},
    {"xfer:backup-suffix",	 "~%Y%m%d%H%M%S~",0,ResMgr::NoClosure},
 
+   // deprecated settings
+   {"xfer:log",		   "log:enable/xfer",   0,ResMgr::AliasValidate},
+   {"xfer:log-file",	   "log:file/xfer",	0,ResMgr::AliasValidate},
+   {"xfer:max-log-size",   "log:max-size/xfer",	0,ResMgr::AliasValidate},
+
 #if USE_SSL
    {"ssl:ca-file",		 "",	  ResMgr::FileReadable,ResMgr::NoClosure},
    {"ssl:crl-file",		 "",	  ResMgr::FileReadable,ResMgr::NoClosure},
@@ -501,5 +503,10 @@ void ResType::ClassInit()
    if(time_style && *time_style)
       Set("cmd:time-style",0,time_style);
 
-   Set("xfer:verify-command",0,PKGDATADIR"/verify-file");
+   SetDefault("xfer:verify-command",0,PKGDATADIR"/verify-file");
+
+   const char *ctx="xfer";
+   SetDefault("log:enabled",ctx,"yes");
+   SetDefault("log:show-time",ctx,"yes");
+   SetDefault("log:file",ctx,dir_file(get_lftp_data_dir(),"transfer_log"));
 }
